#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;

// rekurzivna funkcija koja:
// - popunjava niz manjihLevo koji za svaki element x u delu niza [l, d]
//   izracunava broj elemenata u delu [l, d] koji su levo od x i manji od x
// - popunjava niz vecihDesno koji za svaki element x u delu niza [l, d]
//   izracunava broj elemenata u delu [l, d] koji su desno od x i veci od x
// - kao propratni efekat sortira niz
// Tmp su pomocni nizovi
void izbroj(vector<int>& a, int l, int d, vector<int>& aTmp,
            vector<int>& manjihLevo, vector<int>& manjihLevoTmp,
            vector<int>& vecihDesno, vector<int>& vecihDesnoTmp) {
  if (d - l >= 1) {
    // delimo niz u delove [l, s] i [s+1, d]
    int s = l + (d - l) / 2;
    
    // rekurzivno obradjujemo obe polovine
    izbroj(a, l, s, aTmp,
           manjihLevo, manjihLevoTmp,
           vecihDesno, vecihDesnoTmp);
    izbroj(a, s+1, d, aTmp,
           manjihLevo, manjihLevoTmp,
           vecihDesno, vecihDesnoTmp);

    // vrsimo objedinjavanje dva sortirana niza, popunjavajuci
    // pri tom podatke o elementima manjim levo i vecim desno
    // prvo se sve smesta u pomocne nizove    
    int i = l, i0 = l, j = s+1, j0 = s + 1, k = 0;
    while (i <= s || j <= d)
      if (i <= s && (j > d || a[i] <= a[j])) {
        manjihLevoTmp[k] = manjihLevo[i];
        while (j0 <= d && a[j0] <= a[i])
          j0++;
        vecihDesnoTmp[k] = vecihDesno[i] + (d - j0 + 1);
        aTmp[k++] = a[i++];
      } else {
        while(i0 < i && a[i0] < a[j])
          i0++;
        manjihLevoTmp[k] = (i0 - l) + manjihLevo[j];
        vecihDesnoTmp[k] = vecihDesno[j];
        aTmp[k++] = a[j++];
      }
    
    // kopiramo vrednosti iz pomocnih nizova u glavne
    for (int i=0; i<d-l+1; i++){
      a[l+i] = aTmp[i];
      manjihLevo[l+i] = manjihLevoTmp[i];
      vecihDesno[l+i] = vecihDesnoTmp[i];
    }
  }
}

// ulazna tacka u rekurzivnu funkciju 
void izbroj(vector<int>& a, vector<int>& manjihLevo, vector<int>& vecihDesno) {
  vector<int> aTmp(a.size());
  vector<int> manjihLevoTmp(a.size());
  vector<int> vecihDesnoTmp(a.size());
  izbroj(a, 0, a.size() - 1, aTmp,
         manjihLevo, manjihLevoTmp,
         vecihDesno, vecihDesnoTmp);
}

int main() {
  // ucitavamo elemente u niz
  int n;
  cin >> n;
  vector<int> a(n);
  for (int i = 0; i < n; i++)
    cin >> a[i];

  // za svaki element niza izracunavamo broj elemenata levo od njega
  // koji su manji od njega i broj elemenata desno od njega koji su
  // veci od njega
  vector<int> manjihLevo(n, 0), vecihDesno(n, 0);
  izbroj(a, manjihLevo, vecihDesno);
  
  // izracunavamo i ispisujemo broj sortiranih trojki
  const int mod = 1e9;
  int sortiranihTrojki = 0;
  // analiziramo svaki elementi koji moze biti sredisnji element trojke
  for (int i = 1; i < n-1; i++)
    sortiranihTrojki = (sortiranihTrojki + manjihLevo[i]*vecihDesno[i]) % mod; 
  cout << sortiranihTrojki << endl;
  
  return 0;
}
