#include <iostream>
#include <vector>
#include <algorithm>
#include <numeric>

using namespace std;

// rekurzivna funkcija koja:
// - popunjava niz veciDesno koji za svaki element x u delu niza [l, d]
//   izracunava broj elemenata u delu [l, d] koji su desno od x i veci od x
// - kao propratni efekat sortira niz
// - u niz perm upisuje permutaciju niza koja sluzi da se nakon zavrsetka
//   brojevi vecih elemenata mogu pravilno rasporediti na odgovarajuce pozicije
// Tmp su pomocni nizovi
void prebrojVeceDesno(vector<int>& a, int l, int d, vector<int>& aTmp,
                      vector<int>& veciDesno, vector<int>& veciDesnoTmp,
                      vector<int>& perm, vector<int>& permTmp) {
  // ako niz ima bar dva elementa
  if (d - l >= 1) {
    // delimo niz u delove [l, s] i [s+1, d]
    int s = l + (d - l) / 2;
    
    // rekurzivno obradjujemo obe polovine
    prebrojVeceDesno(a, l, s, aTmp, veciDesno, veciDesnoTmp, perm, permTmp);
    prebrojVeceDesno(a, s+1, d, aTmp, veciDesno, veciDesnoTmp, perm, permTmp);

    // vrsimo objedinjavanje dva sortirana niza, popunjavajuci pri tom
    // za svaki element podatke o tome koliko u originalnom nizu ima
    // elemenata koji su veći ili jednaki od njega, a nalaze se desno od njega
    // prvo se sve smesta u pomocne nizove
    int i = l, j = s+1, k = 0;
    while (i <= s || j <= d)
      if (i <= s && (j > d || a[i] <= a[j])) {
        veciDesnoTmp[k] = veciDesno[i] + (d - j + 1);
        permTmp[k] = perm[i];
        aTmp[k++] = a[i++];
      } else {
        veciDesnoTmp[k] = veciDesno[j];
        permTmp[k] = perm[j];
        aTmp[k++] = a[j++];
      }
    
    // kopiramo vrednosti iz pomocnih nizova u glavne
    for (int i=0; i<d-l+1; i++){
      a[l+i] = aTmp[i];
      veciDesno[l+i] = veciDesnoTmp[i];
      perm[l+i] = permTmp[i];
    }

  }
}

// za svaki element u nizu se odredjuje broj elemenata koji su desno
// od njega i veci su od njega
vector<int> prebroj(vector<int>& a) {
  int n = a.size();
  vector<int> tmp(n);
  vector<int> veciDesno(n, 0);
  vector<int> veciDesnoTmp(n);

  // permutacija koja se koristi tokom sortiranja
  vector<int> perm(n);
  // krecemo od inicijalnog rasporeda
  for(int i=0; i<n; i++)
    perm[i] = i;
  //iota(begin(perm), end(perm), 0);
  
  vector<int> permTmp(n);
  prebrojVeceDesno(a, 0, n-1, tmp, veciDesno, veciDesnoTmp, perm, permTmp);

  // rasporedjujemo izracunate brojace na odgovarajuce pozicije
  for (int i = 0; i < n; i++)
    veciDesnoTmp[perm[i]] = veciDesno[i];
  // vracamo konacan rezultat
  return veciDesnoTmp;
}

int main() {
  // ucitavamo elemente u niz
  int n;
  cin >> n;
  vector<int> a(n);
  for (int i = 0; i < n; i++)
    cin >> a[i];

  // za svaki element odredjujemo broj elemenata desno od njega koji
  // su veci od njega
  vector<int> vecihDesno = prebroj(a);

  // obradjujemo q upita
  int q;
  cin >> q;
  for (int i = 0; i < q; i++) {
    int d, k;
    cin >> d >> k;
    if (vecihDesno[d] > k)
      cout << "ne\n";
    else
      cout << "da\n";
  }
  
  return 0;
}
