#include <iostream>
#include <iomanip>
#include <vector>
#include <algorithm>

using namespace std;

// funkcija mnozi dva polinoma p1*p2 sa po 2^k koeficijenata
vector<double> karacuba(const vector<double>& p1, 
                        const vector<double>& p2) {
  // broj koeficijenata polinoma
  int n = p1.size();
  
  // polinome stepena 0 direktno množimo
  if (n == 1)
    return vector<double>{p1[0] * p2[0], 0.0};

  // delimo p1 na dve polovine: a i b
  vector<double> a(n / 2), b(n / 2);
  copy_n(begin(p1), n/2, begin(a));
  copy_n(next(begin(p1), n/2), n/2, begin(b));
  
  // delimo p2 na dve polovine: c i d
  vector<double> c(n / 2), d(n / 2);
  copy_n(begin(p2), n/2, begin(c));
  copy_n(next(begin(p2), n/2), n/2, begin(d));

  // Važi: 
  //   (ax+b)*(cx+d) = a*c*x^2 + ((a+b)*(c+d) - a*c - b*d)*x + b*d

  // rekurzivno računamo a*c i b*d
  vector<double> ac = karacuba(a, c);
  vector<double> bd = karacuba(b, d);

  // izračunavamo a+b (rezultat smeštamo u vektor a)
  for (int i = 0; i < n/2; i++)
    a[i] += b[i];
  // izračunavamo c+d (rezultat smeštamo u vektor c)
  for (int i = 0; i < n/2; i++)
    c[i] += d[i];

  // izračunavamo (a+b)*(c+d)
  vector<double> adbc = karacuba(a, c);
  // izračunavamo (a+b)*(c+d) - a*c - b*d
  for (int i = 0; i < n; i++)
    adbc[i] -= ac[i] + bd[i];

  // sklapamo proizvod iz delova
  vector<double> proizvod(2*n, 0.0);
  for (int i = 0; i < n; i++) {
    proizvod[n + i] += bd[i];
    proizvod[n/2 + i] += adbc[i];
    proizvod[i] += ac[i];
  }

  // vraćamo rezultat
  return proizvod;
}

// najmanji broj oblika 2^k koji je veci ili jednak od n
int stepenDvojke(int n) {
  int s = 1;
  while (s < n)
    s <<= 1;
  return s;
}

vector<double> ucitajPolinom() {
  int n;
  cin >> n;
  vector<double> p(n+1, 0.0);
  for (int i = 0; i <= n; i++)
    cin >> p[i];
  return p;
}

int main() {
  vector<double> p1 = ucitajPolinom();
  int n1 = p1.size() - 1;
  vector<double> p2 = ucitajPolinom();
  int n2 = p2.size() - 1;
  int s1 = stepenDvojke(p1.size());
  int s2 = stepenDvojke(p2.size());
  int s = max(s1, s2);
  p1.resize(s, 0.0); p2.resize(s, 0.0);

  vector<double> r = karacuba(p1, p2);
  cout << n1 + n2 << endl;
  for (int i = 0; i <= n1 + n2; i++)
    cout << fixed << showpoint << setprecision(2) << r[i] << " ";
  cout << endl;
  return 0;
}
